ListExtensions<T> extension

on

Methods

combs(int n) List<List<T>>

Available on List<T>, provided by the ListExtensions extension

Returns the combinations of K distinct lists selected from the N elements of a list.
interleave(T x) List<List<T>>

Available on List<T>, provided by the ListExtensions extension

Returns all the ways to insert a new element into a list.
perms() List<List<T>>

Available on List<T>, provided by the ListExtensions extension

Returns all the permutation of a list.
product(int repeat) List<List<T>>

Available on List<T>, provided by the ListExtensions extension

Returns all the Cartesian product of a list.
subs() List<List<T>>

Available on List<T>, provided by the ListExtensions extension

Returns the all partial list of the list.
tails() List<List<T>>

Available on List<T>, provided by the ListExtensions extension

Returns all the rest of the elements by deleting the first element of the list in order.