ListExtensions<T> extension
- on
-
- List<
T>
- List<
Methods
-
combs(
int n) → List< List< T> > -
Available on List<
Returns the combinations of K distinct lists selected from the N elements of a list.T> , provided by the ListExtensions extension -
interleave(
T x) → List< List< T> > -
Available on List<
Returns all the ways to insert a new element into a list.T> , provided by the ListExtensions extension -
perms(
) → List< List< T> > -
Available on List<
Returns all the permutation of a list.T> , provided by the ListExtensions extension -
product(
int repeat) → List< List< T> > -
Available on List<
Returns all the Cartesian product of a list.T> , provided by the ListExtensions extension -
subs(
) → List< List< T> > -
Available on List<
Returns the all partial list of the list.T> , provided by the ListExtensions extension -
tails(
) → List< List< T> > -
Available on List<
Returns all the rest of the elements by deleting the first element of the list in order.T> , provided by the ListExtensions extension